#
# spec file for package owncloud
#
# Copyright (c) 2012-2015 ownCloud, Inc.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.
#
# Please submit bugfixes, issues or comments via http://github.com/owncloud/
#

# 0, 1: support nginx as alternative to apache
%define have_nginx 0

# name used as apache alias and topdir for php code.
%define owncloud	owncloud	

# CAUTION: keep in sync with debian.rules
### apache variables
%define nginx_confdir /etc/nginx/conf.d
%define apache_serverroot /var/www
%define apache_confdir /etc/httpd/conf.d
%define oc_user apache
%define oc_group apache
%define __jar_repack 0
## only for backwards compatibility with our 7.0 package layout.
%define oc_apache_web_dir 	%{apache_serverroot}/%{owncloud}

# CAUTION: keep in sync with debian.rules
## traditional layout
%define oc_dir		%{oc_apache_web_dir}
%define oc_config_dir 	%{oc_apache_web_dir}/config
%define oc_data_dir 	%{oc_apache_web_dir}/data
%define oc_data_pdir 	%{oc_apache_web_dir}

%define ocphp		php
%define ocphp_bin	/usr/bin
%define ochttpd		httpd

Name:           owncloud

# Downloaded from http://download.owncloud.org/community/testing/owncloud-8.1.0alpha2.tar.bz2

## define prerelease %nil, if this is *not* a prerelease.
%define prerelease %nil
%define base_version 8.1.1
# % define tar_version % {base_version}% {prerelease}
%define tar_version 8.1.1beta1


%if 0%{?centos_version} == 600 || 0%{?fedora_version} || "%{prerelease}" == ""
# For beta and rc versions we use the ~ notation, as documented in
# http://en.opensuse.org/openSUSE:Package_naming_guidelines
Version:       	%{base_version}
%if "%{prerelease}" == ""
Release:        12.1
%else
Release:       	0.12.1.%{prerelease}
%endif
%else
Version:       	%{base_version}~%{prerelease}
Release:        12.1
%endif

# Source0:        http://download.owncloud.org/community/testing/owncloud-%{tar_version}.tar.bz2
Source0:        http://download.owncloud.org/community/owncloud-8.1.1.tar.bz2
Source2:        README
Source3:        README.SELinux
Source4:        README.packaging
Source10:       robots.txt
Source11:	apache_secure_data
%if %{have_nginx}
Source12:       nginx_owncloud.conf
%endif
Source100:      obs_check_deb_spec.sh
Url:            http://www.owncloud.org
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
Summary:        The ownCloud Server - Private file sync and share server
License:        AGPL-3.0 and MIT
Group:          Productivity/Networking/Web/Utilities

###############################################
## All build requires go into the main package.
BuildRequires:  %{ochttpd}

# https://github.com/owncloud/core/issues/11576
# at CentOS6, we need policycoreutils-python for semanage.
BuildRequires:	policycoreutils-python


###############################################
## Misc unsorted preview and database requires also go into the main package.
## You can install owncloud-* subpackages only to avoid these dependencies.
Requires:       sqlite

# %if 0%{?fedora_version}
# missing at CentOS/RHEL: do we really need that?
# Requires:       php-pear-MDB2-Driver-mysqli
# BuildRequires:  php-pear-MDB2-Driver-mysqli
# %endif


Requires:       curl
Requires:	%{name}-server-core   = %{version}
Requires:	%{name}-config-apache = %{version}

# must have nil on the first line to survive source-validator.
%define require_standard_apps %{nil}\
Requires:	%{name}-3rdparty              = %{version} \
Requires:	%{name}-app-activity          = %{version} \
Requires:	%{name}-app-files_pdfviewer   = %{version} \
Requires:	%{name}-app-files_trashbin    = %{version} \
Requires:	%{name}-app-firstrunwizard    = %{version} \
Requires:	%{name}-app-templateeditor    = %{version} \
Requires:	%{name}-app-user_ldap         = %{version} \
Requires:	%{name}-app-external          = %{version} \
Requires:	%{name}-app-files_external    = %{version} \
Requires:	%{name}-app-files_sharing     = %{version} \
Requires:	%{name}-app-files_versions    = %{version} \
Requires:	%{name}-app-gallery           = %{version} \
Requires:	%{name}-app-user_webdavauth   = %{version} \
Requires:	%{name}-app-files             = %{version} \
Requires:	%{name}-app-files_locking     = %{version} \
Requires:	%{name}-app-files_texteditor  = %{version} \
Requires:	%{name}-app-files_videoviewer = %{version} \
Requires:	%{name}-app-provisioning_api  = %{version} \
Requires:	%{name}-app-user_external     = %{version} \
Requires:	%{name}-app-encryption	      = %{version}


## not recommended for Linux packages.
# Requires:	#{name}-app-updater           = #{version}
Obsoletes:	%{name}-app-updater           < %{version}
# ex-apps:
Obsoletes:	%{name}-app-files_encryption  < %{version}

# Finally require all subpackages to make a standalone system.
Requires:       %{name}-server        = %{version}
Requires:	%{name}-config-apache = %{version}

%description
ownCloud Server provides you a private file sync and share
cloud. Host this server to easily sync business or private documents
across all your devices, and share those documents with other users of
your ownCloud server on their devices.

File system layout here is identical with tar or zip distributions.

This package installs as follows:
oc_dir:        %{oc_dir}
oc_data_dir:   %{oc_data_dir}
oc_config_dir: %{oc_config_dir}

ownCloud - Your Cloud, Your Data, Your Way!  www.owncloud.org

#####################################################

%package server
License:      AGPL-3.0 and MIT
Group:        Development/Libraries/PHP
Summary:      Common code server for ownCloud
%require_standard_apps

# CAUTION: Keep in sync with core/lib/private/util.php: many dependencies are defined there.

# In ownCloud 8.0, we use PHP 5.4 language features that 5.3 does not support
Requires:       sqlite
Requires:       %{ocphp} >= 5.4.0
Requires:       %{ocphp}-json %{ocphp}-mbstring %{ocphp}-process %{ocphp}-xml %{ocphp}-zip
# core#13357, core#13944
Requires:	%{ocphp}-posix %{ocphp}-gd

# apps/user_ldap		
Requires:	%{ocphp}-ldap

# %if 0%{?fedora_version}
# missing at CentOS/RHEL: do we really need that?
## Requires:       php-pear-Net-Curl
## BuildRequires:  php-pear-Net-Curl
# %endif

# https://github.com/owncloud/core/issues/11576
# at CentOS6, we need policycoreutils-python for semanage.
Requires:	policycoreutils-python
# at centOS7 to avoid a blank page. Class 'PDO' not found at \/var\/www\/html\/owncloud\/3rdparty\/doctrine
Requires:       %{ocphp}-pdo

# The server core is common code
Provides:	owncloud-enterprise-server = %{version}
Provides:	owncloud-server-core = %{version}

%description  server
The %{name}-server package contains the common owncloud server core.
To run the servers, you either need to also install an ${name}-config-* package
or configure the server yourself for your system.

File system layout here is identical with tar or zip distributions.

This package installs as follows:
oc_dir:        %{oc_dir}
oc_data_dir:   %{oc_data_dir}
oc_config_dir: %{oc_config_dir}


#####################################################
%package config-apache
Obsoletes:    %{name} < 7.9.9
License:      AGPL-3.0 and MIT
Group:        Development/Libraries/PHP
Summary:      Apache setup for ownCloud
Requires:     %{name}-server-core = %{version}

Requires:       %{ochttpd}

%description config-apache
This sub-package configures an apache webserver for owncloud.
Install only, if you us to make changes to your webserver setup.

File system layout here is identical with tar or zip distributions.

This package installs as follows:
oc_dir:        %{oc_dir}
oc_data_dir:   %{oc_data_dir}
oc_config_dir: %{oc_config_dir}
apache_confdir:    %{apache_confdir}
apache_serverroot: %{apache_serverroot}



#####################################################
%if %{have_nginx}
%package config-nginx
Obsoletes:    %{name} < 7.9.9
License:      AGPL-3.0 and MIT
Group:        Development/Libraries/PHP
Summary:      Apache setup for ownCloud
Requires:     %{name}-server-core = %{version}

# nginx is in the epel repository, register that first.
# Oops: this fails at build time: PreReq:	epel-release
Requires:       nginx

%description config-nginx
This sub-package configures an nginx webserver for owncloud.
Install only, if you us to make changes to your webserver setup.

File system layout here is identical with tar or zip distributions.

This package installs as follows:
oc_dir:        %{oc_dir}
oc_data_dir:   %{oc_data_dir}
oc_config_dir: %{oc_config_dir}
apache_confdir:    %{apache_confdir}
apache_serverroot: %{apache_serverroot}
%endif



#####################################################

%package 3rdparty
Obsoletes:    %{name} < 7.9.9
License:      AGPL-3.0 and MIT and others
Group:        Development/Libraries/PHP
Summary:      3rdparty libraries for ownCloud
Requires:     %{name}-server-core = %{version}
%description 3rdparty
3rdparty libraries needed for running ownCloud.
Contained in separate package due to different source code licenses.

#####################################################
# oc_app_package
#
# Caution: This macro definition must be below the main package chunk.
#          Otherwise the specfile parser in obs fails.
#
# Parameters:
#  %%1	appname as seen in the file system
#
%define oc_app_package() 			\
%package app-%{1}				\
Obsoletes:      %{name} < 7.9.9 		\
Summary:	The ownCloud application %{1} add-on for %{name}-server \
Group:          Productivity/Networking/Web/Utilities	\
Requires:	%{name}-server-core = %{version} \
%{?2:%{2}} 					\
%description app-%{1} 				\
This package provides the ownCloud application %{1} for %{name}-server \
						\
oc_dir:        %{oc_dir} 			\
						\
%files app-%{1}					\
%defattr(0644,%{oc_user},%{oc_group},0755)	\
%dir %{oc_dir}/apps/%{1}			\
%{oc_dir}/apps/%{1}/*				\
%{nil}


%prep
%setup -q -n owncloud
cp %{SOURCE2} .
cp %{SOURCE3} .
cp %{SOURCE4} .
cp %{SOURCE10} .
#%%patch0 -p0

# obs_check_deb_spec.sh
# pushd $RPM_SOURCE_DIR
# sh %{SOURCE100} all
# popd

# remove .bower.json .bowerrc .gitattributes .gitmodules
find . -name .bower\* -print -o -name .git\* -print | xargs rm

%build
# obsolete stuff, to be removed from tar-balls.
rm -f indie.json
rm -f l10n/l10n.pl

# do not build updater app.
rm -rf apps/updater

%install
# no server side java code contained, alarm is false
export NO_BRP_CHECK_BYTECODE_VERSION=true
idir=$RPM_BUILD_ROOT/%{oc_dir}
mkdir -p $RPM_BUILD_ROOT/%{oc_dir}
# fix https://github.com/owncloud/enterprise/issues/570
mkdir -p $RPM_BUILD_ROOT/%{oc_dir}/assets
mkdir -p $RPM_BUILD_ROOT/%{oc_data_dir}
mkdir -p $RPM_BUILD_ROOT/%{oc_config_dir}
cp -aRf * $idir
rm -rf $idir/debian.*{install,rules,control}
mv $idir/config/* $idir/config/.??* $RPM_BUILD_ROOT/%{oc_config_dir} || true
cp -aRf .htaccess $idir
## done in owncloud-server post install script
# ln -s %{oc_data_dir} $idir/data

# make oc_apache_web_dir a compatibility symlink
mkdir -p $RPM_BUILD_ROOT/%{apache_serverroot}

if [ ! -f $idir/robots.txt ]; then
  install -p -D -m 644 %{SOURCE10} $idir/robots.txt
fi

# create the AllowOverride directive
# apache_secure_data
install -p -D -m 644 %{SOURCE11}   $RPM_BUILD_ROOT/%{apache_confdir}/owncloud.conf
sed -i -e"s|@@OC_DIR@@|%{oc_dir}|g" $RPM_BUILD_ROOT/%{apache_confdir}/owncloud.conf

%if %{have_nginx}
# nginx_owncloud.conf
install -p -D -m 644 %{SOURCE12}   $RPM_BUILD_ROOT/%{nginx_confdir}/owncloud.conf
sed -i -e"s|@@OC_DIR@@|%{oc_dir}|g" $RPM_BUILD_ROOT/%{nginx_confdir}/owncloud.conf
%endif

# relabel data directory for SELinux to allow ownCloud write access on redhat platforms
%if 0%{?fedora_version} || 0%{?rhel_version} || 0%{?centos_version}
if [ -x /usr/sbin/sestatus ] ; then \
  sestatus | grep -E '^(SELinux status|Current).*(enforcing|permissive)' > /dev/null && {
    semanage fcontext -a -t httpd_sys_rw_content_t '%{oc_data_dir}'
    restorecon '%{oc_data_dir}'
    semanage fcontext -a -t httpd_sys_rw_content_t '%{oc_config_dir}'
    restorecon '%{oc_config_dir}'
    semanage fcontext -a -t httpd_sys_rw_content_t '%{oc_dir}/apps'
    restorecon '%{oc_dir}/apps'
    semanage fcontext -a -t httpd_sys_rw_content_t '%{oc_dir}/assets'
    restorecon '%{oc_dir}/assets'
  }
fi
true
%endif


%postun config-apache
# remove SELinux ownCloud label if not updating
[ $1 -eq 0 ] || exit 0
%if 0%{?fedora_version} || 0%{?rhel_version} || 0%{?centos_version}
if [ -x /usr/sbin/sestatus ] ; then \
  sestatus | grep -E '^(SELinux status|Current).*(enforcing|permissive)' > /dev/null && {
    semanage fcontext -l | grep '%{oc_data_dir}' && {
      semanage fcontext -d -t httpd_sys_rw_content_t '%{oc_data_dir}'
      restorecon '%{oc_data_dir}'
    }
    semanage fcontext -l | grep '%{oc_config_dir}' && {
      semanage fcontext -d -t httpd_sys_rw_content_t '%{oc_config_dir}'
      restorecon '%{oc_config_dir}'
    }
    semanage fcontext -l | grep '%{oc_dir}/apps' && {
      semanage fcontext -d -t httpd_sys_rw_content_t '%{oc_dir}/apps'
      restorecon '%{oc_dir}/apps'
    }
    semanage fcontext -l | grep '%{oc_dir}/assets' && {
      semanage fcontext -d -t httpd_sys_rw_content_t '%{oc_dir}/assets'
      restorecon '%{oc_dir}/assets'
    }
  }
fi
true
%endif

%pre config-apache
# avoid fatal php errors, while we are changing files
# https://github.com/owncloud/core/issues/10953
#
# TBD: https://github.com/owncloud/core/issues/12125
#  The code below is bad user experience.  We should
#  put the existing owncloud in maintenance mode,
#  apply our changes, reload (not restart!) apache, then
#  exit maintenance mode.
#
# We don't do this for new installs. Only for updates.
# If the first argument to pre is 1, the RPM operation is an initial installation.
# If the argument is 2, the operation is an upgrade from an existing version to a new one.
if [ $1 -gt 1 -a ! -s /tmp/apache_stopped_during_owncloud_install ]; then	
  echo "%{name} update: Checking for running Apache"
  # FIXME: this above should make it idempotent -- a requirement with openSUSE.
  # it does not work.
  service %{ochttpd} status | grep running > /tmp/apache_stopped_during_owncloud_install
  service %{ochttpd} stop
fi
if [ -s /tmp/apache_stopped_during_owncloud_install ]; then
  echo "%{name} pre-install: Stopping Apache"
fi

%post config-apache
if [ $1 -eq 1 ]; then
    echo "%{name}-config-apache: First install complete"
else
    echo "%{name}-config-apache: Upgrade complete"
fi

# pre/postinstall/uninstall script of owncloud-config-apache-8.0.0~beta2-13.1.noarch.rpm modifies filelist!
#[  206s] filelist diff:
#[  206s] --- //.build_patchrpmcheck1	2015-01-28 19:09:33.903497088 +0000
#[  206s] +++ //.build_patchrpmcheck2	2015-01-28 19:09:34.391497077 +0000
#[  206s] @@ -4694,9 +4694,8 @@
#[  206s] -.....U...    /srv/www/htdocs/owncloud/config
#[  206s] -.M...U...    /srv/www/htdocs/owncloud/config/.htaccess
#[  206s] -.M...U...    /srv/www/htdocs/owncloud/config/config.sample.php
#[  206s] +.M.......    /srv/www/htdocs/owncloud/config/.htaccess
#[  206s] +.M.......    /srv/www/htdocs/owncloud/config/config.sample.php
#
## FIXME: probably we have no chance to chmod the files when apache comes in.
## config can be chown-ed to root:www after the initial DB config is done.
# if [ -e %{oc_data_dir} ]; then
#   chown -R %{oc_user}:%{oc_group} %{oc_data_dir}
# fi
# if [ -e %{oc_config_dir} ]; then
#   chown -R %{oc_user}:%{oc_group} %{oc_config_dir}
# fi

if [ -s /tmp/apache_stopped_during_owncloud_install ]; then
  echo "%{name}-config-apache: Restarting"
  ## If we stopped apache in pre section, we now should restart. -- but *ONLY* then!
  ## Maybe delegate that task to occ upgrade? They also need to handle this, somehow.
  service %{ochttpd} start
fi

if [ ! -s /tmp/apache_stopped_during_owncloud_install ]; then
  echo "%{name}-config-apache: Reloading"
  service %{ochttpd} status && service %{ochttpd} reload || service %{ochttpd} start
fi
rm -f /tmp/apache_stopped_during_owncloud_install

%pre server
#pre_oc_7_8_upgrade

if [ $1 -eq 1 ]; then
    echo "%{name}-server: First install starting"
else
    echo "%{name}-server: Upgrade starting"
fi
# https://github.com/owncloud/core/issues/12125
if [ -x %{ocphp_bin}/php -a -f %{oc_dir}/occ ]; then
  echo "%{name}-server: occ maintenance:mode --on"
  su %{oc_user} -s /bin/sh -c "cd %{oc_dir}; PATH=%{ocphp_bin}:$PATH php ./occ maintenance:mode --on" || true
  echo yes > /tmp/occ_maintenance_mode_during_owncloud_install
fi

%preun server

%post server
if [ $1 -eq 1 ]; then
    echo "%{name}-server First install complete"
else
    echo "%{name}-server Upgrade complete"
fi

# must ignore errors with e.g.  '|| true' or we die in openSUSEs horrible post build checks.
# https://github.com/owncloud/core/issues/12125 needed occ calls.
# https://github.com/owncloud/core/issues/17583 correct occ usage.
if [ -s /tmp/occ_maintenance_mode_during_owncloud_install ]; then
  if [ -x %{ocphp_bin}/php -a -f %{oc_dir}/occ ]; then
    # https://github.com/owncloud/core/issues/14351
    su %{oc_user} -s /bin/sh -c "cd %{oc_dir}; PATH=%{ocphp_bin}:$PATH php ./occ maintenance:mode --off" || true
    echo "%{name}-server: occ upgrade"
    su %{oc_user} -s /bin/sh -c "cd %{oc_dir}; PATH=%{ocphp_bin}:$PATH php ./occ upgrade" || true
    su %{oc_user} -s /bin/sh -c "cd %{oc_dir}; PATH=%{ocphp_bin}:$PATH php ./occ maintenance:mode --off" || true
  fi
fi
rm -f /tmp/occ_maintenance_mode_during_owncloud_install

%postun
if [ 0$1 -eq 0 ]; then
  echo "An ownCloud installation consists of multiple packages."
  echo "You just uninstalled %{name} . This is what remains installed:"
  rpm -qa 'owncloud-*'
fi

%if %{have_nginx}
%post config-nginx
# ownCloud installs with user and group permissions suitable for apache
# We cannot have more than one oc_user and one oc_group
# let nginx access via group.
#
# FIXME: We should try to add acl's and only resort to chmod/chgrp
# if nothing else helps.
# CAUTION: openSUSE bails out on this postinstall script at build time.
# Running the scripts is pointless at build time, but obs still wants to do that.
chgrp -R nginx %{oc_dir}/apps/ %{oc_config_dir}/ %{oc_data_dir}/ || true
chmod -R a+w   %{oc_dir}/apps/ %{oc_config_dir}/ %{oc_data_dir}/ || true
%endif


%clean
rm -rf "$RPM_BUILD_ROOT"

%oc_app_package activity
%oc_app_package files_pdfviewer
%oc_app_package files_trashbin
%oc_app_package firstrunwizard
%oc_app_package templateeditor
%oc_app_package user_ldap		Requires:%{ocphp}-ldap
%oc_app_package external
%oc_app_package files_external
%oc_app_package files_sharing
%oc_app_package files_versions
%oc_app_package gallery
%oc_app_package user_webdavauth
%oc_app_package files
%oc_app_package files_locking
%oc_app_package files_texteditor
%oc_app_package files_videoviewer
%oc_app_package provisioning_api
%oc_app_package user_external		Requires:owncloud-app-external
%oc_app_package encryption

%post app-files
# https://github.com/owncloud/core/issues/18043
if [ -x %{ocphp_bin}/php -a -f %{oc_dir}/occ ]; then
    # https://github.com/owncloud/core/issues/14351
    su %{oc_user} -s /bin/sh -c "cd %{oc_dir}; PATH=%{ocphp_bin}:$PATH php ./occ maintenance:mode --off" || true
    echo "%{name}-server: occ upgrade"
    su %{oc_user} -s /bin/sh -c "cd %{oc_dir}; PATH=%{ocphp_bin}:$PATH php ./occ upgrade" || true
    su %{oc_user} -s /bin/sh -c "cd %{oc_dir}; PATH=%{ocphp_bin}:$PATH php ./occ maintenance:mode --off" || true
fi


%files
%defattr(-,root,root,-)
%doc README README.packaging

%files server
%defattr(0644,root,%{oc_group},0755)
%doc README README.SELinux
%dir %{oc_dir}
%doc %{oc_dir}/AUTHORS
%doc %{oc_dir}/COPYING-AGPL
%doc %{oc_dir}/README*
%{oc_dir}/core
%{oc_dir}/db_structure.xml
%{oc_dir}/index.php
%{oc_dir}/lib
%{oc_dir}/ocs
%{oc_dir}/ocs-provider
%{oc_dir}/public.php
%{oc_dir}/remote.php
%{oc_dir}/settings
%{oc_dir}/status.php
%{oc_dir}/cron.php
%{oc_dir}/robots.txt
%{oc_dir}/index.html
%{oc_dir}/console.php
%{oc_dir}/version.php

%defattr(0755,%{oc_user},%{oc_group},0775)
%{oc_dir}/themes
%{oc_dir}/occ
%dir %{oc_dir}/assets
%dir %{oc_dir}/apps
%exclude %{oc_dir}/apps/*
%{oc_config_dir}/*
%{oc_config_dir}/.htaccess
%{oc_dir}/.htaccess
%dir %{oc_data_dir}
%dir %{oc_config_dir}

%files config-apache
%defattr(-,%{oc_user},%{oc_group},0775)
%config %attr(0644,root,root) %{apache_confdir}/owncloud.conf

%if %{have_nginx}
%files config-nginx
%defattr(-,%{oc_user},%{oc_group},0775)
# CentOS: /etc/nginx/conf.d/
%config %attr(0644,root,root) /etc/nginx/conf.d/owncloud.conf
%dir /etc/nginx
%dir /etc/nginx/conf.d
%endif


%files 3rdparty
%defattr(0644,%{oc_user},%{oc_group},0755)
%dir %{oc_dir}/3rdparty
%{oc_dir}/3rdparty/*

%changelog
* Sat Aug  8 2015 jw@owncloud.com
- Update to version 8.1.1
* Fri Aug  7 2015 jw@owncloud.com
- Fixed https://github.com/owncloud/core/issues/18043
  with extra calls to occ upgrade during owncloud-app-files post install.
* Fri Aug  7 2015 jw@owncloud.com
- Cleanup specfile: No more references to optional fhs.
- Cleanup specfile: No more owncloud-server-scl-php54 package.
- Calling occ from its directory according to https://github.com/owncloud/core/issues/17583
- Calling occ with the correct php for CentOS_6_PHP55 and friends.
* Mon Aug  3 2015 jw@owncloud.com
- Update to version 8.1.1~RC1
* Wed Jul 29 2015 jw@owncloud.com
- CentOS_6_PHP55: using %%{ochttpd} to switch to httpd24-httpd
* Wed Jul 29 2015 jw@owncloud.com
- CentOS_6_PHP55: using %%{ochttpd} to switch to httpd24-httpd
* Fri Jul 24 2015 jw@owncloud.com
- Update to version 8.1.1~beta1
* Fri Jul 24 2015 jw@owncloud.com
- Don't provide owncloud-server-scl-php54 for CentOS_6_PHP55 and up.
  That should help with https://github.com/owncloud/core/issues/17654
* Fri Jul 17 2015 jw@owncloud.com
- Relaxed php > 5.4.0 requirement for CentOS_6_PHP55 and friends.
  They provide their php by different names and often useless version numbers.
* Fri Jul  3 2015 jnweiger@gmail.com
- Update to version 8.1.0
* Thu Jul  2 2015 jw@owncloud.com
- suse needs explicit dependency to php-fileinfo
* Wed Jul  1 2015 jw@owncloud.com
- Version number patched back to 3 digits. 8.1.0~RC2
* Wed Jul  1 2015 jnweiger@gmail.com
- Update to version 8.1~RC2
* Fri Jun 19 2015 jw@owncloud.com
- moving .htaccess from config-apache to server*
  Fix https://github.com/owncloud/core/issues/17032
* Fri Jun 19 2015 jw@owncloud.com
- don't provide unversioned owncloud-server-core -- this
  fools strictly versioned dependencies in update scenarios.
- fix upgrade messages.
- Explicitly Require php-fileinfo for SUSE
- obsolete owncloud-app-files_encryption
* Thu Jun 18 2015 jw@owncloud.com
- Update to 8.1.0~RC1
* Tue Jun  2 2015 jw@owncloud.com
- fixed https://github.com/owncloud/core/issues/16132
* Tue May 19 2015 jw@owncloud.com
- Update to 8.1.0~Beta2
* Wed May 13 2015 jw@owncloud.com
- https://github.com/owncloud/updater/issues/122
  Actively remove updater app. Not requiring is not enough, apparently.
  People still install it.
* Wed May 13 2015 jw@owncloud.com
- Fixed obs_check_deb_spec.sh to survive debian checks, when run on Fedora.
* Fri May  8 2015 jw@owncloud.com
- Update to 8.1.0~Beta1
  Removed apps: encrryption_dummy
* Thu Apr 23 2015 jw@owncloud.com
- update to 8.1.0~Alpha2
  Removed apps: files_encryption
* Thu Apr 16 2015 jw@owncloud.com
- update to 8.1.0~Alpha1
  Added apps: encryption encryption_dummy
* Thu Apr 16 2015 jw@owncloud.com
- updated to 8.0.3-RC2
* Thu Apr 16 2015 jw@owncloud.com
- Fixed https://github.com/owncloud/enterprise/issues/570
  Adding assets folder
* Sat Mar 28 2015 jw@owncloud.com
- Release  "8.0.3" April 6. 2015
  - Fix several Constrain Violation Exceptions
  - Fix misleading Maintenance mode message
  - Timezone fixes for countries with .05 and 0.75 offsets
  - Fix usage of default share folder location
  - Improved MSSQL compatibility
  - Reenable trashbin after failed rename
  - Fix disabling of APCu
  - Do not show update notification on mobile
  - Fix "Only variables should be passed by reference" error log spam
  - Add timeout to curl
  - Makes repair errors and warnings visible for the user when
  - Upgrading on the command line or in the web UI
  - Cron shall not operate in case we are in maintenance mode
  - Disable the cache updater when doing the encryption migration
  - Fix "Error while updating app" error
  - Internal Server Error after attempting to do "occ files:scan"
* Wed Mar 25 2015 jw@owncloud.com
- fixed https://github.com/owncloud/core/issues/14610
  preinst handling of dangling symlinks improved.
* Tue Mar 17 2015 jw@owncloud.com
- Made obs_check_deb_spec.sh ignore 'missing' updater app.
* Fri Mar 13 2015 jw@owncloud.com
- 3rdparty requires server-core.
  Fixed: https://github.com/owncloud/core/issues/14855
- removed obsolete pre/post macros from spec file.
* Wed Mar 11 2015 jw@owncloud.com
- Release  "8.0.2" March 11. 2015
  - Prevent DB errors in certain high load sitatons
  - Fix installation and updating of apps from the app store
  - Fix documentation links
  - Fix file move/copy when out of storage space
  - Disable 3rd party apps during upgrade to prevent breaking ownCloud if incompatible apps are used
  - Fix compatibility with certain MariaDB versions
  - Print app upgrade information to console
  - Detect broken APC versions
  - Fix certain incompatibilities with older PHP 5.4 versions
  - Several smaller fixes
  - updated to 8.0.2
- propagated post_oc_7_8_upgrade pre_oc_7_8_upgrade to all
  subpackages that use the owncloud directory.
  Survivie existing directories
- reverted post_oc_7_8_upgrade pre_oc_7_8_upgrade, only works for openSUSE
* Fri Mar  6 2015 jw@owncloud.com
- update to 8.0.1 Mar 5, 21:40h
* Thu Mar  5 2015 jw@owncloud.com
- updated to 8.0.1 Mar 4, 22:35h
* Wed Mar  4 2015 jw@owncloud.com
- update to 8.0.1
* Tue Feb 24 2015 jw@owncloud.com
- Fixed missing quotes in specfile core#14362
- Factored out dependencies of owncloud into owncloud-server* to make
  owncloud-server-scl-php54 usable on CentOS-6
- No code changes.
* Sun Feb 22 2015 jw@owncloud.com
- fixed RPM license header of owncloud-3dparty package.
* Wed Feb 18 2015 jw@owncloud.com
- fixed  https://github.com/owncloud/core/issues/14351
  disable maintenance:mode explicitly before and after upgrade
* Wed Feb 18 2015 jw@owncloud.com
- fixed https://github.com/owncloud/core/issues/14350
  uninstall message suppressed during upgrade.
* Thu Feb 12 2015 jw@owncloud.com
- centos7 needs php-pdo
* Sun Feb  8 2015 jnweiger@gmail.com
- owncloud-server-scl-php54 requires php54-php-pdo (and php54-php-gd)
  fixes https://github.com/owncloud/core/issues/13917
- owncloud-server-scl-php54 requires php54-php for the apache module.
- and was missing the config dir. Oops.
- on centos: owncloud-config-apache now reloads apache when running or
  starts apache when not running.
* Sat Feb  7 2015 jnweiger@gmail.com
- Update to 8.0.0 final.
  https://github.com/owncloud/core/wiki/ownCloud-8.0-Features
- Added a %%postun warning about remaining subpackages.
- https://github.com/owncloud/core/issues/13917
  Use virtual provides owncloud-server-core that differs from
  package name owncloud-server, as yum always sticks to the package
  of the same name, even if it is uninstallable.
* Fri Feb  6 2015 jw@owncloud.com
- Added php-gd for rhel/centos/fedora to fix
  https://github.com/owncloud/core/issues/13944
  (Was already present for SUSE only.)
* Fri Feb  6 2015 jw@owncloud.com
- most parts of debian.control had no effect. Reason stil unclear.
  moving owncloud.conf before dh_install should fix
  https://github.com/owncloud/core/issues/13914
- owncloud-server-scl-php54 must require php54 without a version number
  to help with  https://github.com/owncloud/core/issues/13917
* Fri Feb  6 2015 jw@owncloud.com
- added owncloud-server-scl-php54 (for CentOS-6) to provide an
  owncloud-server that requires php54 (>= 5.4.0) instead of php (>=5.4).
* Thu Feb  5 2015 jw@owncloud.com
- Update to RC2
  https://github.com/owncloud/core/wiki/ownCloud-8.0-Features
* Thu Feb  5 2015 jw@owncloud.com
- With ownCloud 8.0 we use PHP 5.4 language features that 5.3 does not support
- Requires: php* >= 5.4.0 added to the spec file.
* Tue Feb  3 2015 jw@owncloud.com
- suse fails with no good error message with Obsoletes: owncloud < 8.0.0
  retry with Obsoletes: < 7.9.9
* Tue Feb  3 2015 jw@owncloud.com
- try fix https://github.com/owncloud/core/issues/13835
  Using Replaces: (<< 8.0.0) + Breaks: (<< 8.0.0) and Obsoletes: owncloud < 8.0.0
* Mon Feb  2 2015 jw@owncloud.com
- Update to RC1
  https://github.com/owncloud/core/wiki/ownCloud-8-Features
* Fri Jan 30 2015 jw@owncloud.com
- Requires and Provides were at the wrong place in the specfile.
  Moved before Description, so that the got into the rpm header data.
* Fri Jan 30 2015 jw@owncloud.com
- reload_apache() function added.
- apache config FollowSymlinks enabled, needed for FHS.
* Thu Jan 29 2015 jw@owncloud.com
- fixed garbage filter to catch .bower* and .git* --
  failed on the enterprise tar ball. grr.
- fixed syntax error in preinst.
* Wed Jan 28 2015 jw@owncloud.com
- standard upgrade procedure implemented in %%pre and %%post of owncloud-server.
  (deb version TBD)
- reverted the FHS compliance. See the experimental owncloud-fhs packages for this.
* Tue Jan 27 2015 jnweiger@gmail.com
- Apache alias for /usr/share/owncloud added.
- fixed many path names.
- Improved obs_check_deb_spec.sh
- moved .htaccess to owncloud-config-apache
- new debian.rules from scratch -- much closer semantic to *.spec than before.
- debian dependencies moved to the respective subpackage.
* Mon Jan 26 2015 jw@owncloud.com
- beta2 release
* Fri Jan 23 2015 jw@owncloud.com
- started README.packaging
- added missing %%files section for the main package.
* Tue Jan 20 2015 jw@owncloud.com
- beta1 release.
  * owncloud/search folder is gone.
  * specfile refactored to produce the following sub packages:
    owncloud-server
    owncloud-config-apache
    owncloud-app-*	(tbd)
* Mon Jan 12 2015 jw@owncloud.com
- owncloud 8.0 initial checkin.
  Changes relative to 7.0.4
  * Files removed: 3rdparty/System.php 3rdparty/PEAR/* 3rdparty/PEAR-LICENSE
  * apps added: files_locking provisioning_api
  * apps removed (as seen in 7.0.4):
    admin_dependencies_chk 0.02
    bookmarks 0.4
    calendar 0.6.4
    contacts 0.3.0.18
    documents 0.8.2
    search_lucene 0.5.3
  * https://apps.owncloud.com/ currently has the following apps:
    Calendar 0.0.1 July 7 2014
    Contacts 0.0.1 July 7 2014
    Bookmarks 0.0.1 July 7 2014
    Documents 0.0.1 July 7 2014
    Search (Lucene) 0.0.1 July 7 2014
  FIXME: updates needed there!!!
